#
# spec file for package xsp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           xsp
Url:            http://go-mono.com/
Version:        3.0.11
Release:        lp150.1.5
Summary:        Small Web Server Hosting ASP.NET
License:        MIT
Group:          Productivity/Networking/Web/Servers
Source:         https://github.com/mono/xsp/archive/%{version}.tar.gz
Source1:        xsp.conf
Patch1:         %{name}-3.0.11-fix-bashisms.patch
Patch2:         mono-440-build-fix.patch
Patch3:         mono-4-install.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  mono-data-oracle
BuildRequires:  mono-data-sqlite
BuildRequires:  mono-devel >= 2.10.0
BuildRequires:  mono-nunit
BuildRequires:  mono-web
BuildRequires:  monodoc-core
BuildRequires:  pkgconfig
BuildRequires:  sqlite
%if 0%{?suse_version} >= 1330
BuildRequires:  strip-nondeterminism
Requires(pre):	user(wwwrun)
Requires(pre):  group(www)
Requires(post): user(wwwrun)
Requires(post): group(www)
%endif
Requires(post): %insserv_prereq %fillup_prereq
%define _fwdefdir /etc/sysconfig/SuSEfirewall2.d/services
%define xspConfigsLocation %{_sysconfdir}/xsp/2.0
%define xspAvailableApps %{xspConfigsLocation}/applications-available
%define xspEnabledApps %{xspConfigsLocation}/applications-enabled

%description
The XSP server is a small Web server that hosts the Mono System.Web
classes for running what is commonly known as ASP.NET.

%define mcsver %({ mcs --version | awk '{print $5}' | cut -f1 -d"." ; mcs --version | awk '{print $5}' | cut -f2 -d"." ; } | xargs printf "%03d")

%if 0%{?mcsver} >= 4000
%define target2_dir xsp2
%define target4_dir xsp4
%else
%define target2_dir 2.0
%define target4_dir 4.5
%endif

%prep
%setup -q
%patch1 -p1
%if 0%{?mcsver} >= 4004
%patch2 -p1
%endif
%if 0%{?mcsver} >= 4000
%patch3 -p1
%endif

%build
NOCONFIGURE=1 ./autogen.sh
# Cannot use the configure macro because noarch-redhat-linux is not recognized by the auto tools in the tarball
./configure --prefix=%{_prefix} \
	    --libexecdir=%{_prefix}/lib \
	    --libdir=%{_prefix}/lib \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --sysconfdir=%{_sysconfdir}
make

%install
[ -x /usr/bin/strip-nondeterminism ] && strip-nondeterminism docs/Mono.FastCGI/Mono.FastCGI.zip docs/Mono.WebServer/Mono.WebServer.zip
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_prefix}/lib/xsp/unittests
mkdir -p %{buildroot}%{_datadir}
mv %{buildroot}%{_prefix}/lib/pkgconfig %{buildroot}%{_datadir}
mkdir -p %{buildroot}/%{_fwdefdir}
mkdir -p %{buildroot}/%{xspAvailableApps}
mkdir -p %{buildroot}/%{xspEnabledApps}
mkdir -p %{buildroot}/etc/init.d/
mkdir -p %{buildroot}/etc/logrotate.d/
mkdir -p %{buildroot}/srv/xsp2
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}/run/xsp2
mkdir -p %{buildroot}/usr/lib/tmpfiles.d/
install -m 644 man/mono-asp-apps.1 %{buildroot}%{_mandir}/man1/mono-asp-apps.1
install -m 644 packaging/opensuse/sysconfig.xsp2 %{buildroot}%{_fillupdir} 
install -m 644 packaging/opensuse/xsp2.fw %{buildroot}/%{_fwdefdir}/xsp2
install -m 644 packaging/opensuse/xsp2.logrotate %{buildroot}/etc/logrotate.d/xsp2
install -m 755 packaging/opensuse/xsp2.init %{buildroot}/etc/init.d/xsp2
install -m 755 tools/mono-asp-apps/mono-asp-apps %{buildroot}%{_bindir}/mono-asp-apps
install -m 755 %{SOURCE1} %{buildroot}/usr/lib/tmpfiles.d/
%fdupes %{buildroot}

%post
%{fillup_and_insserv -n xsp2 xsp2}
install -d -m 0711 --owner=wwwrun --group=www /run/xsp2

%preun
%stop_on_removal xsp2

%postun
%restart_on_update xsp2
%{insserv_cleanup}

%files
%defattr(-,root,root)
%doc NEWS README
%{_bindir}/*
%{_datadir}/pkgconfig/*
%dir %{_prefix}/lib/mono/%{target2_dir}
%{_prefix}/lib/mono/%{target2_dir}/Mono.WebServer2.dll
%{_prefix}/lib/mono/%{target2_dir}/fastcgi-mono-server2.exe
%{_prefix}/lib/mono/%{target2_dir}/mod-mono-server2.exe
%{_prefix}/lib/mono/%{target2_dir}/xsp2.exe
%dir %{_prefix}/lib/mono/%{target4_dir}
%{_prefix}/lib/mono/%{target4_dir}/Mono.WebServer2.dll
%{_prefix}/lib/mono/%{target4_dir}/fastcgi-mono-server4.exe
%{_prefix}/lib/mono/%{target4_dir}/mod-mono-server4.exe
%{_prefix}/lib/mono/%{target4_dir}/xsp4.exe
%{_prefix}/lib/mono/gac/Mono.WebServer2
%{_prefix}/lib/mono/gac/fastcgi-mono-server2
%{_prefix}/lib/mono/gac/fastcgi-mono-server4
%{_prefix}/lib/mono/gac/mod-mono-server2
%{_prefix}/lib/mono/gac/mod-mono-server4
%{_prefix}/lib/mono/gac/xsp2
%{_prefix}/lib/mono/gac/xsp4
%{_prefix}/lib/monodoc/sources/Mono.WebServer.*
%{_prefix}/lib/monodoc/sources/Mono.FastCGI.*
%{_prefix}/lib/xsp
%{_prefix}/share/man/*/*
%config %{_fwdefdir}/xsp2
%config /etc/init.d/xsp2
%config /etc/logrotate.d/xsp2
%{_fillupdir}/*
%attr(0711,wwwrun,www) /srv/xsp2
%ghost %attr(0711,wwwrun,www) /run/xsp2
/usr/lib/tmpfiles.d/
%{_sysconfdir}/%{name}

%define __find_provides env sh -c 'filelist=($(cat)) && { printf "%s\\n" "${filelist[@]}" | /usr/lib/rpm/find-provides && printf "%s\\n" "${filelist[@]}" | /usr/bin/mono-find-provides ; } | sort -u'
%define __find_requires env sh -c 'filelist=($(cat)) && { printf "%s\\n" "${filelist[@]}" | /usr/lib/rpm/find-requires && printf "%s\\n" "${filelist[@]}" | /usr/bin/mono-find-requires ; } | sort -u'

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Sep 29 2017 jengelh@inai.de
- Add missing dependencies for %%post.
* Wed Aug  2 2017 i@marguerite.su
- fix factory build, add missing wwwrun user.
* Mon Apr 24 2017 bwiedemann@suse.com
- fix to correct version
  because only factory has strip-nondeterminism atm
  (and 42.3 which we ignore here)
* Fri Apr 21 2017 bwiedemann@suse.com
- use strip-nondeterminism to make build fully reproducible
* Sun Mar 19 2017 fwdsbs.to.11df@xoxy.net
- Add %%insserv_prereq %%fillup_prereq requires:
  * Fix build for factory and tumbleweed
* Sun Jun  5 2016 fwdsbs.to.11df@xoxy.net
- Added patch mono-440-build-fix.patch:
  * Alter mono libraries search path in order to fix build with mono 4.4.0 and up
- Added mono-4-install.patch:
  * Alter xsp mono package path for mono 4.0 and up in order to fix xsp2 startup crash
* Sun May 10 2015 Led <ledest@gmail.com>
- fix bashism in init script
- add patches:
  * xsp-3.0.11-fix-bashisms.patch
* Fri Jan 16 2015 p.drouand@gmail.com
- Update to version 3.11
  + Changelog/NEWS files have not been updated
- Use download Url as source
- Add autoconf and automake; required because of autogen script
- Minimal required version of mono is 2.10.0; fix mono dependency
  version
- Remove redundant %%clean section
- Remove obsolete conditional macros
- Use autogen script instead of autoreconf
* Fri Aug  1 2014 sfalken@opensuse.org
- Changed /var/run to /run in package, to fix rpmlint check failures in
  oS:Factory
- Modified:
    xsp.spec
    xsp.conf
* Thu Aug 11 2011 aj@suse.de
- Run fdupes
- Mark /var/run/xsp2 as %%ghost and create it during package install
- Add xsp.conf to create directory in /var/run
* Wed Apr 27 2011 ajorgensen@novell.com
- Update to 2.10.2
  * http://www.go-mono.com/archive/2.10.2
* Tue Feb 22 2011 ajorgensen@novell.com
- Update to 2.10
  * http://www.go-mono.com/archive/2.10
* Fri Jan  7 2011 ajorgensen@novell.com
- Update to 2.8.2
  * Fix for CVE-2010-4225, bnc#660070
  * http://www.go-mono.com/archive/2.8.2
* Tue Oct 12 2010 ajorgensen@novell.com
- Update to 2.8
  * http://www.go-mono.com/archive/2.8
* Tue Apr 27 2010 ajorgensen@novell.com
- Update to 2.6.4
  * http://www.mono-project.com/Release_Notes_Mono_2.6.4
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.6.3
  * http://www.mono-project.com/Release_Notes_Mono_2.6.3
* Tue Jan 26 2010 ajorgensen@novell.com
- Update to 2.6
  * http://www.mono-project.com/Release_Notes_Mono_2.6
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.4.2
  * http://www.mono-project.com/Release_Notes_Mono_2.4.2
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Wed Oct  1 2008 ajorgensen@novell.com
- Update to 2.0 RC4
  * Fixes bnc#431121
* Mon Sep 22 2008 ajorgensen@novell.com
- Update to 2.0 RC3
  * Defaults to 2.0 profile (fixes a bug in mod_mono)
* Tue Aug 26 2008 ajorgensen@novell.com
- Update to 2.0
  * Fixes bnc#350779, bnc#359783, bnc#363404, bnc#372220,
    bnc#324204, bnc#408723
  * Sync with mod_mono changes
* Tue Apr 22 2008 wberrier@suse.de
- update to 1.9.1 (bugfix release)
  - Output date header (instead of asp.net doing it)
* Tue Mar 25 2008 wberrier@suse.de
- update to 1.9
  - minor test updates
  - BaseRequestBroker fix: Check if the request ID is valid inside
  the lock.
* Mon Jan 14 2008 wberrier@suse.de
- update to 1.2.6
  - FastCGI support
* Fri Aug 31 2007 wberrier@suse.de
- xsp_1.2.5_p5_final.patch: Fix for regression in the request
  broker
* Fri Aug 17 2007 wberrier@suse.de
- xsp_1.2.5_p4.patch.bz2: Bugfixes found in 1.2.5
  - bugs: 81699, 81906, 82379, 82057
  - fixes ability to handle large (GB) uploads (needed for iFolder)
* Fri Aug  3 2007 wberrier@suse.de
- Update to 1.2.5
  - More robust exception handling
  - Fixed permissions bits for non executable scripts
  - virtual host support
  - New Documentation for Mono.WebServer
  - Improved event handling
* Wed Jun  6 2007 wberrier@novell.com
- Remove unnecessary path defines (prefix, sysconfdir)
- Update to 1.2.4
  - fix some race conditions and crashes
  - add tracing support
* Fri Apr 13 2007 wberrier@novell.com
- add %%debug_package so debug packages get created
* Wed Apr 11 2007 wberrier@novell.com
- Add mono dep/req for older distros
* Fri Mar  2 2007 wberrier@suse.de
- Update Update to 1.2.3
  - Bug fix #80230 (prevents possible nullref)
  - Support for response header encoding
* Tue Jan 23 2007 ro@suse.de
- drop requires for gnome-filesystem
* Sat Dec  2 2006 wberrier@suse.de
- Update to 1.2.1 (Fate #301111)
  - Bugfixes:
  - close the connection if there's an error reading the headers
  (including assembly loading exceptions due to a bad installation).
  - kill the warning that everyone is worried about.
* Sat Oct 21 2006 wberrier@suse.de
- Update to 1.1.18
  - 2.0 updates
* Thu Oct 19 2006 wberrier@suse.de
- Add mono-devel to fix bnc #213576 (missing provides)
* Tue Sep  5 2006 wberrier@suse.de
- Update to 1.1.17.1 bugfix release
- Read from the stream, not the socket as the socket data is
  encrypted when using SSL.
* Wed Aug 30 2006 wberrier@suse.de
- Update to 1.1.17
  - Added support for X.509 client certificates
  - Update to handle newly created AppDomains
* Tue Aug  1 2006 wberrier@suse.de
- update to 1.1.16.1
- better connection handling
- fixes bugs: 77698,78034,78621
* Wed Apr 26 2006 wberrier@suse.de
- Security update (remove all the duplicated slashes
  and don't do an extra Replace on non-windows.) and minor fix for
  [#78034].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 wberrier@suse.de
- Update to 1.1.13, clean up deps
* Fri Nov 11 2005 wberrier@suse.de
- Update to 1.1.10, set libdir to lib/
* Fri Oct  7 2005 wberrier@suse.de
- Update to 1.1.9.2 and cleanup (I Don't think noarch mono needs
  libexec, so I disabled the patch)
* Tue Jul 19 2005 sbrabec@suse.cz
- Build as noarch (#81109).
* Fri Jul 15 2005 sbrabec@suse.cz
- Updated to version 1.0.9 (#96776).
* Mon Feb 21 2005 clahey@suse.de
- Updated to 1.0.6.
* Mon Feb  7 2005 ro@suse.de
- use /usr/lib/mono
* Tue Dec 14 2004 clahey@suse.de
- New package.
